@@ -19,6 +19,8 @@ from time import sleep
 if __name__ == '__main__' and __package__ is None:
     from os import sys, path
     sys.path.append(path.dirname(path.dirname(path.abspath(__file__))))
+else:
+    print("__name__", __name__, "__package__", __package__)
 
 from spotinst_agent.agentinit import init__configuration
 from spotinst_agent.taskmanager import TaskManager
